
import java.util.StringTokenizer;

import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;
import javax.swing.event.EventListenerList;

public class Traductor {

    protected EventListenerList listenerList = new EventListenerList();
    
    public static final int FRANCES = 0;
    public static final int ESPAOL = 1;
    public static final int INGLES = 2;
    
    private final ChangeEvent e = new ChangeEvent(this);

    public static final int NUM_IDIOMAS = 3;

    private int idiomaOrigen;
    private int idiomaDestino;

    private String[][] diccionario = {
            { "Longue", "Rdiut", "Pain", "Bombe", "Moto"
                    },
            { "Largo", "Barato", "Pan", "Petardo", "Moto"
                    },
            { "Long", "Cheap", "Bread", "Bomb", "Motorbike"
                    } };

    private static String[] cadena = { "Francs", "Espaol",
            "Ingls" };

    public Traductor() {
        this.idiomaOrigen = ESPAOL;
        this.idiomaDestino = INGLES;
    }

    public void addChangeListener(ChangeListener cl){
        this.listenerList.add(ChangeListener.class, cl);
    }
    
    public void removeChangeListener(ChangeListener cl){
        this.listenerList.remove(ChangeListener.class, cl);
    }
    
    protected void fireChangePerformed(ChangeEvent event){

        Object[] listeners = listenerList.getListenerList();

        //Mtodo invocado cuando se quiere generar un evento
        for (int i = listeners.length - 2; i >= 0; i -= 2) {
            if (listeners[i] == ChangeListener.class) {
                ((ChangeListener) listeners[i + 1])
                        .stateChanged(event);
            }
        }
    }
    
    public static String getCadenaIdioma(int codIdioma) {
        return cadena[codIdioma];
    }

    public void setIdiomaOrigen(int idiomaOrigen) {
        this.idiomaOrigen = idiomaOrigen;
        this.fireChangePerformed(e);
    }

    public void setIdiomaDestino(int idiomaDestino) {
        this.idiomaDestino = idiomaDestino;
        this.fireChangePerformed(e);
    }

    public int getIdiomaOrigen() {
        return idiomaOrigen;
    }

    public void invierteIdioma() {
        int aux;
        aux = idiomaOrigen;
        idiomaOrigen = idiomaDestino;
        idiomaDestino = aux;
        this.fireChangePerformed(e);
    }

    public int getIdiomaDestino() {
        return idiomaDestino;
    }

    public String[] getPalabras(int codIdioma) {
        return diccionario[codIdioma];
    }

    public String traducePalabra(String palabra) {
        return this.traducePalabra(palabra, this.idiomaOrigen,
                this.idiomaDestino);
    }

    public String traducePalabra(String palabra, int codOrigen,
            int codDestino) {

        int i = 0;
        boolean encontrado = false;
        while ((i < diccionario[ESPAOL].length) && !encontrado) {
            if (palabra
                    .equalsIgnoreCase(diccionario[codOrigen][i])) {
                encontrado = true;
            } else {
                i++;
            }
        }

        if (encontrado) {
            return diccionario[codDestino][i];
        } else {
            return "X";
        }
    }

    public String traduceTexto(String texto) {
        return this.traduceTexto(texto, this.idiomaOrigen,
                this.idiomaDestino);
    }

    public String traduceTexto(String texto, int codOrigen,
            int codDestino) {

        StringBuffer traduccion = new StringBuffer();

        StringTokenizer st = new StringTokenizer(texto, " \n");

        while (st.hasMoreTokens()) {
            String palabra = st.nextToken();
            traduccion.append(this.traducePalabra(palabra,
                    codOrigen, codDestino));
            traduccion.append(" ");
        }

        return traduccion.toString();
    }
}